@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 __author__ = "Mikhail Fedosov (tbs.micle@gmail.com)"
-__version__ = "0.1.3.7"
+__version__ = "0.1.3.8"
 
 # http://code.activestate.com/recipes/577708-check-for-package-updates-on-pypi-works-best-in-pi/
 # http://stackoverflow.com/questions/287871/print-in-terminal-with-colors-using-python
@@ -35,7 +35,7 @@ class symbols:
 	""" Status symbols
 	"""
 	FAIL = u"✖ "
-	UPDATE = u"⤤ "
+	UPDATE = u"+ "
 	OK = u"✓ "
 
 	@classmethod
